@@ -1,4 +1,5 @@
 use crate::nodes::*;
+use std::ops::RangeInclusive;
 
 /// # Code Block
 ///
@@ -31,13 +32,25 @@ pub struct CodeNode {
     inline: bool,
     highlight: bool,
     code: String,
-    file: Option<String>,
-    high_line: Vec<usize>,
+    show_file_name: Option<String>,
+    /// None means not show line_number
+    show_line_number: Option<usize>,
+    highlight_lines: Vec<RangeInclusive<usize>>,
+    hide_lines: Vec<RangeInclusive<usize>>,
 }
 
 impl Default for CodeNode {
     fn default() -> Self {
-        Self { lang: String::from("text"), code: String::new(), inline: false, highlight: false, file: None, high_line: vec![] }
+        Self {
+            lang: String::from("text"),
+            code: String::new(),
+            inline: false,
+            highlight: false,
+            show_file_name: None,
+            show_line_number: None,
+            highlight_lines: vec![],
+            hide_lines: vec![],
+        }
     }
 }
 
@@ -54,7 +67,7 @@ impl Display for CodeNode {
 
 impl CodeNode {
     #[inline]
-    pub fn into_node(self, range: Option<(u32, u32)>) -> ASTNode {
+    pub fn into_node(self, range: Option<OffsetRange>) -> ASTNode {
         ASTNode { value: ASTKind::CodeNode(Box::new(self)), range }
     }
     #[inline]
@@ -62,14 +75,31 @@ impl CodeNode {
         self.lang = lang;
         return self;
     }
+
     #[inline]
-    pub fn set_highlight_line(mut self, lines: Vec<usize>) -> Self {
-        self.high_line = lines;
+    pub fn set_file_name(mut self, name: String) -> Self {
+        self.show_file_name = Some(name);
         return self;
     }
     #[inline]
-    pub fn set_file_name(mut self, name: String) -> Self {
-        self.file = Some(name);
+    pub fn clear_highlight_line(mut self) -> Self {
+        self.highlight_lines.clear();
+        return self;
+    }
+    #[inline]
+    pub fn set_highlight_line(mut self, lines: Vec<RangeInclusive<usize>>) -> Self {
+        self.highlight_lines = lines;
+        return self;
+    }
+
+    #[inline]
+    pub fn add_highlight_line(mut self, line: usize) -> Self {
+        self.highlight_lines.push(RangeInclusive::new(line, line));
+        return self;
+    }
+    #[inline]
+    pub fn add_highlight_range(mut self, lines: RangeInclusive<usize>) -> Self {
+        self.highlight_lines.push(lines);
         return self;
     }
 }
@@ -80,13 +110,13 @@ impl CodeNode {
     /// ```
     #[inline]
     pub fn code_inline(code: String) -> Self {
-        Self { lang: String::from("text"), inline: true, highlight: false, code, file: None, high_line: vec![] }
+        Self { lang: String::from("text"), inline: true, highlight: false, code, ..Default::default() }
     }
     /// ```notedown
     /// `s`
     /// ```
     #[inline]
     pub fn code_block(lang: String, code: String) -> Self {
-        Self { lang, inline: false, highlight: true, code, file: None, high_line: vec![] }
+        Self { lang, inline: false, highlight: true, code, ..Default::default() }
     }
 }
