@@ -19,7 +19,7 @@ impl Display for Header {
 
 impl Header {
     #[inline]
-    pub fn into_node(self, range: Option<(u32, u32)>) -> ASTNode {
+    pub fn into_node(self, range: Option<OffsetRange>) -> ASTNode {
         ASTNode { value: ASTKind::Header(Box::new(self)), range }
     }
 }
